@@ -63,7 +63,7 @@ break    any_:label ; @stmt @token @new @cmpl
 continue any_:label ;  @stmt @token @new @cmpl
 goto ANY:label ;  @stmt @token @new @cmpl
 
-try {:trycase STT_CATCH:catch {:finally   @stmt  @token @new  @name @cmpl
+try {:try STT_CATCH:catch {:finally   @stmt  @token @new  @name @cmpl
 catch EXPTN:type VARN:name {:catch   @token @stmt
 finally @token
 throw expr:expt ;   @stmt  @token @new @name @cmpl
@@ -92,7 +92,7 @@ letmulti VARN*:names[]               @stmt
 print  expr*:values[]  @stmt @token @new  @cmpl
 assert pexpr:bool ;    @token @stmt @new 
 #utest  pexpr:bool {:testcase  @stmt @test
-man   ANY:keyword ;  @stmt @new
+#man   ANY:keyword ;  @stmt @new
 
 '''
 
@@ -115,11 +115,11 @@ TOKEN = '''
 |= bitore        
 &= bitande       
 ?\?= ALTLET      
-? QUESTION       @top  @P2
-.. SUBSETE       @P2
-..< SUBSET       @P2
-..+ OFFSET       @P2
-: COLON          @P2
+? QUESTION       @P2
+.. Itr           @op @P2 @A1
+..< SUBSET       @P99
+..+ OFFSET       @P99
+: COLON          @P99
 ?\? ALT          @op    @P2
 
 || OR            @P5
@@ -146,9 +146,10 @@ to? To                 @op @A2  @P9
 <= Lte                 @op @A2   @P9
 > Gt                   @op @A2   @P9
 >= Gte                 @op @A2   @P9
+=~  Match              @op @A2   @P9
 
 |  Lor                  @op @top  @P11
-%% Fmt                 @op @2    @P12 @A2
+%% Fmt                 @op @2    @P12
 
 << Lshift              @op @2    @P15
 >> Rshift              @op @2    @P15
@@ -168,7 +169,7 @@ to? To                 @op @A2  @P9
 NUM                    @system @top @const @P99
 STR                    @system @top @const @P99
 TSTR                   @system @top @const @P99
-FMTSTR                 @system @top @P99
+EVAL                   @system @top @P99
 LABEL                  @system @top
 METAN                  @system @top @eos
 PROPN                  @system @top @P99
@@ -706,11 +707,11 @@ new_StmtSTMT1(Ctx *ctx, knh_tokens_t *tc)
     case TT_SEMICOLON:
         return new_StmtDONE(ctx);''')
             continue
-        if tk.TT == 'TT_QUESTION' :
-            f.write('''
-    case TT_QUESTION:
-        return new_StmtMAN(ctx, tc);''')
-            continue
+#        if tk.TT == 'TT_QUESTION' :
+#            f.write('''
+#//   case TT_QUESTION:
+#//      return new_StmtMAN(ctx, tc);''')
+#            continue
         if tk.TT == 'TT_ERR' :
             f.write('''
     case TT_ERR:
