@@ -54,22 +54,16 @@ extern "C" {
 #define knh_Bytes_value(o)     (o)->buf
 #define knh_Bytes_last(o)      ((o)->buf + (o)->size)
 #define knh_Bytes_tochar(b)  (char*)knh_Bytes_value(b)
-#define knh_BytesConv_struct_copy NULL
-#define knh_BytesConv_struct_compare NULL
 #define KNH_SIZE(v)         knh_size(v)
 #define B(c)     new_bytes(c)
 #define B2(c,n)   new_bytes__2(c,n)
 #define STEXT(c)  new_bytes__2(c,sizeof(c)-1)
 #define ISB(t,c) (t.len == (sizeof(c)-1) && knh_strncmp((char*)t.buf,c,t.len) == 0)
+#define knh_BytesConv_struct_copy NULL
+#define knh_BytesConv_struct_compare NULL
 #define CLASS_newid          ((knh_class_t)-1)
 #define CLASS_unknown        ((knh_class_t)-2)
 #define knh_Class_cid(c)     (knh_class_t)(c)->cid
-#define knh_ClassMap_struct_copy    NULL
-#define knh_ClassMap_struct_compare  NULL
-#define knh_tstruct_isNative(sid)   (sid < KONOHA_TSTRUCT_SIZE)
-#define knh_ClassStruct_struct_copy    NULL
-#define knh_Class_getMethod(ctx, c, mn)    knh_Class_getMethod__(ctx, c, mn, 0)
-#define knh_Class_findMethod(ctx, c, mn)   knh_Class_getMethod__(ctx, c, mn, 1)
 #define IS_SPEC(o)   (CLASS_IntUnit <= knh_Object_cid(o)  && knh_Object_cid(o) <= CLASS_Vocabulary)
 #define KNH_FLAG_TF_NN                KNH_FLAG_T0
 #define TYPE_ISNULLABLE(t)            ((t & KNH_FLAG_TF_NN)==0)
@@ -84,6 +78,12 @@ extern "C" {
 #define TYPE_any                      CLASS_Any
 #define NNTYPE_any                    CLASS_any
 #define TYPEN(type)  knh_TYPEN(ctx,type)
+#define knh_ClassMap_struct_copy    NULL
+#define knh_ClassMap_struct_compare  NULL
+#define knh_tstruct_isNative(sid)   (sid < KONOHA_TSTRUCT_SIZE)
+#define knh_ClassStruct_struct_copy    NULL
+#define knh_Class_getMethod(ctx, c, mn)    knh_Class_getMethod__(ctx, c, mn, 0)
+#define knh_Class_findMethod(ctx, c, mn)   knh_Class_getMethod__(ctx, c, mn, 1)
 #define knh_Connection_struct_copy    NULL
 #define knh_Connection_struct_compare  NULL
 #define KNH_STDIN          (((Context*)ctx)->in)
@@ -240,8 +240,8 @@ extern "C" {
 
 
 #define KNH_LOCALn(n)                 (lbp_[n].o)
-#define KNH_LSETv(ctx, n, v)          KNH_SETv(ctx, lbp_[n].o, v) 
-#define KNH_LCLOSE(ctx)               ((Context*)ctx)->ebp = lbp_ - 1 
+#define KNH_LSETv(ctx, n, v)          KNH_SETv(ctx, lbp_[n].o, v)
+#define KNH_LCLOSE(ctx)               ((Context*)ctx)->ebp = lbp_ - 1
 #define KNH_LPUSH(ctx,v) \
 	((Context*)ctx)->ebp++; \
 	KNH_SETv(ctx, ((Context*)ctx)->ebp[0].o, v); \
@@ -260,15 +260,15 @@ extern "C" {
 #define KNH_FLAG_PF_NOCOMMA     KNH_FLAG_T5
 #define KNH_FLAG_PF_EMPTY       KNH_FLAG_T6
 #define KNH_FLAG_PF_BOL         KNH_FLAG_T7
-#define KNH_THROW(ctx, e) knh_throw(ctx, UP(e))
+#define KNH_THROW(ctx, e) knh_throw(ctx, UP(e), KNH_SAFEFILE(__FILE__), __LINE__)
 #define KNH_THROWs(ctx, s) \
-	knh_throwException(ctx, new_Exception__b(ctx, B(s))); \
+	knh_throwException(ctx, new_Exception__b(ctx, B(s)), KNH_SAFEFILE(__FILE__), __LINE__); \
 
 
 #define KNH_THROWf(ctx, fmt, ...) \
 	char throwbuf_[256]; \
 	knh_snprintf(throwbuf_, sizeof(throwbuf_), fmt, ## __VA_ARGS__); \
-	knh_throwException(ctx, new_Exception__b(ctx, B(throwbuf_))); \
+	knh_throwException(ctx, new_Exception__b(ctx, B(throwbuf_)), KNH_SAFEFILE(__FILE__), __LINE__); \
 
 
 #define TODO_THROW(ctx) knh_throw_TODO(ctx, (char*)__FILE__, __LINE__, (char*)__FUNCTION__)
@@ -281,7 +281,6 @@ KNHAPI(knh_bytes_t) knh_Bytes_tobytes(Bytes *o);
 KNHAPI(void) knh_Bytes_clear(Bytes *o);
 KNHAPI(void) knh_Bytes_putc(Ctx *ctx, Bytes *o, int ch);
 KNHAPI(void) knh_Bytes_write(Ctx *ctx, Bytes *o, knh_bytes_t v);
-KNHAPI(void) konoha_addDataBaseDriver(Ctx *ctx, char *alias, knh_db_drvapi_t *d);
 KNHAPI(Exception*) new_Exception(Ctx *ctx, String *msg);
 KNHAPI(Exception*) new_Exception__b(Ctx *ctx, knh_bytes_t msg);
 KNHAPI(Exception*) new_Exception__errno(Ctx *ctx);
@@ -301,18 +300,19 @@ KNHAPI(void) knh_write_TAB(Ctx *ctx, OutputStream *w);
 KNHAPI(void) knh_write_BOL(Ctx *ctx, OutputStream *w);
 KNHAPI(void) knh_format(Ctx *ctx, OutputStream *w, knh_methodn_t mn, Any *x, Any *m);
 KNHAPI(void) knh_printf(Ctx *ctx, OutputStream *w, char *fmt, ...);
-KNHAPI(ResultSet*) new_ResultSet(Ctx *ctx, Connection *conn, size_t column_size, knh_rshdlr_t *rsptr);
-KNHAPI(void) knh_ResultSet_initMetaInfo(Ctx *ctx, ResultSet *o, size_t n, knh_type_t type, String *name);
-KNHAPI(void) knh_ResultSet_initData(Ctx *ctx, ResultSet *o);
+KNHAPI(ResultSet*) new_ResultSet(Ctx *ctx, knh_dbcur_t *dbcur, size_t column_size);
+KNHAPI(void) knh_ResultSet_setName(Ctx *ctx, ResultSet *o, size_t n, String *name);
 KNHAPI(void) knh_ResultSet_setInt(Ctx *ctx, ResultSet *o, size_t n, knh_integer_t value);
 KNHAPI(void) knh_ResultSet_setFloat(Ctx *ctx, ResultSet *o, size_t n, knh_float_t value);
-KNHAPI(void) knh_ResultSet_setBytes(Ctx *ctx, ResultSet *o, size_t n, knh_bytes_t t);
+KNHAPI(void) knh_ResultSet_setText(Ctx *ctx, ResultSet *o, size_t n, knh_bytes_t t);
+KNHAPI(void) knh_ResultSet_setBLOB(Ctx *ctx, ResultSet *o, size_t n, knh_bytes_t t);
 KNHAPI(void) knh_ResultSet_setNULL(Ctx *ctx, ResultSet *o, size_t n);
 KNHAPI(void) konoha_addAliasURN(Ctx *ctx, char *alias, char *urn);
+KNHAPI(String*) new_String_bconv(Ctx *ctx, String *s, f_bconv bconv);
 KNHAPI(void) konoha_addParserDriver(Ctx *ctx, char *alias, knh_parser_drvapi_t *d);
 KNHAPI(ClassSpec*) new_Vocabulary(Ctx *ctx, char *lang, char *defval, ...);
 KNHAPI(void) konoha_addVocabularyMapper(Ctx *ctx, knh_class_t scid, char *text);
-KNHAPI(String*) new_String_bconv(Ctx *ctx, String *s, f_bconv bconv);
+KNHAPI(void) konoha_addDBDriver(Ctx *ctx, char *alias, knh_db_drvapi_t *d);
 KNHAPI(void) konoha_addIODriver(Ctx *ctx, char *alias, knh_iodrv_t *d);
 KNHAPI(void) konoha_addRegexDriver(Ctx *ctx, char *alias, knh_regex_drvapi_t *d);
 KNHAPI(size_t) knh_stat_usedMemorySize(void);
@@ -339,8 +339,8 @@ KNHAPI(void) konoha_addDriver(Ctx *ctx, char *name, int type, void *drv);
 KNHAPI(char*) KNH_SAFEFILE(char *file);
 KNHAPI(void) konoha_shell(Ctx *ctx);
 KNHAPI(void) knh_throw_TODO(Ctx *ctx, char *file, int line, char *func);
-KNHAPI(void) knh_throwException(Ctx *ctx, Exception *e);
-KNHAPI(void) knh_throw(Ctx *ctx, Object *e);
+KNHAPI(void) knh_throwException(Ctx *ctx, Exception *e, char *file, int line);
+KNHAPI(void) knh_throw(Ctx *ctx, Object *e, char *file, int line);
 
 #ifdef __cplusplus
 }
