@@ -144,6 +144,7 @@ knh_index_t knh_bytes_index(knh_bytes_t v, knh_int_t ch);
 knh_index_t knh_bytes_rindex(knh_bytes_t v, knh_int_t ch);
 knh_bytes_t knh_bytes_first(knh_bytes_t t, knh_int_t loc);
 knh_bytes_t knh_bytes_last(knh_bytes_t t, knh_int_t loc);
+knh_bytes_t knh_bytes_skipscheme(knh_bytes_t t);
 char *knh_format_bytes(char *buf, size_t bufsiz, knh_bytes_t t);
 knh_bytes_t knh_bytes_subset(knh_bytes_t t, size_t s, size_t e);
 knh_bytes_t knh_bytes_offlen(knh_bytes_t t, size_t off, size_t len);
@@ -203,7 +204,6 @@ void knh_Class_addMethod(Ctx *ctx, knh_class_t cid, Method *mtd);
 Method* knh_Class_getMethod__(Ctx *ctx, knh_class_t this_cid, knh_methodn_t mn, knh_bool_t gen);
 void knh_cfield_dump(Ctx *ctx, knh_cfield_t *f, size_t offset, size_t fsize, OutputStream *w);
 /* ../class/konoha/knh_Connection.c */
-knh_db_drvapi_t * knh_System_getDataBaseDriver(Ctx *ctx, knh_bytes_t name);
 void knh_Connection_struct_init(Ctx *ctx, knh_Connection_struct *b, int init, Object *cs);
 void knh_Connection_struct_traverse(Ctx *ctx, knh_Connection_struct *b, f_traverse ftr);
 void knh_Connection_open(Ctx *ctx, Connection *o, String *urn);
@@ -328,19 +328,22 @@ void knh_DictSet__dump(Ctx *ctx, DictSet *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Exception.c */
 void knh_Exception_struct_init(Ctx *ctx, knh_Exception_struct *b, int init, Object *cs);
 void knh_Exception_struct_traverse(Ctx *ctx, knh_Exception_struct *b, f_traverse gc);
-Exception* new_Exception(Ctx *ctx, String *msg);
-Exception* new_Exception__b(Ctx *ctx, knh_bytes_t msg);
+Exception* knh_Exception_new__init(Ctx *ctx, Exception *o, String *e, String *msg, Object *bag);
 Exception* new_Exception__Nue(Ctx *ctx, knh_Nue_t *nue);
 /* ../class/konoha/knh_Exception_api1.c */
-void knh_Exception__s(Ctx *ctx, Exception *b, OutputStream *w, String *m);
-void knh_Exception__dump(Ctx *ctx, Exception *b, OutputStream *w, String *m);
+METHOD knh__Exception_new(Ctx *ctx, knh_sfp_t *sfp);
+int knh_Exception_isa(Ctx *ctx, Exception *o, String *msg);
+METHOD knh__Exception_opIsa(Ctx *ctx, knh_sfp_t *sfp);
+void knh_Exception__s(Ctx *ctx, Exception *o, OutputStream *w, String *m);
+void knh_Exception__k(Ctx *ctx, Exception *o, OutputStream *w, String *m);
+void knh_Exception__dump(Ctx *ctx, Exception *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_ExceptionHandler.c */
 void knh_ExceptionHandler_struct_init(Ctx *ctx, knh_ExceptionHandler_struct *b, int init, Object *cs);
 void knh_ExceptionHandler_struct_traverse(Ctx *ctx, knh_ExceptionHandler_struct *b, f_traverse gc);
 ExceptionHandler* new_ExceptionHandler(Ctx *ctx);
 Object *knh_ExceptionHandler_fdefault(Ctx *ctx, knh_class_t cid);
-void knh_ExceptionHandler_longjmp(Ctx *ctx, ExceptionHandler *b, Exception *e);
-Exception* knh_ExceptionHandler_getCaughtException(ExceptionHandler *b);
+void knh_ExceptionHandler_longjmp(Ctx *ctx, ExceptionHandler *o, Exception *e);
+Exception* knh_ExceptionHandler_getCaughtException(ExceptionHandler *o);
 /* ../class/konoha/knh_Float.c */
 Float* new_FloatX0(Ctx *ctx, knh_class_t cid, knh_float_t value);
 Float* new_FloatX(Ctx *ctx, knh_class_t cid, knh_float_t value);
@@ -415,19 +418,19 @@ void knh_HashSet_add__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode);
 void knh_HashSet_remove__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode);
 void knh_HashSet_clear(Ctx *ctx, HashSet *o);
 /* ../class/konoha/knh_InputStream.c */
-void KNHINIT init_InputStream(Ctx *ctx);
 void knh_InputStream_struct_init(Ctx *ctx, knh_InputStream_struct *b, int init, Object *cs);
-void knh_InputStream_struct_traverse(Ctx *ctx, knh_InputStream_struct *b, f_traverse gc);
+void knh_InputStream_struct_traverse(Ctx *ctx, knh_InputStream_struct *b, f_traverse ftr);
 Object *knh_InputStream_open(Ctx *ctx, InputStream *o, String *urn);
-int knh_InputStream_getc(Ctx *ctx, InputStream *b);
-size_t knh_InputStream_read(Ctx *ctx, InputStream *b, char *buf, size_t bufsiz);
-String* knh_InputStream_readLine(Ctx *ctx, InputStream *b);
-void knh_InputStream_close(Ctx *ctx, InputStream *b);
-InputStream *new_InputStream__FILE(Ctx *ctx, FILE *fp);
-InputStream *new_InputStream__Bytes(Ctx *ctx, Bytes *ba, size_t s, size_t e);
+int knh_InputStream_getc(Ctx *ctx, InputStream *o);
+size_t knh_InputStream_read(Ctx *ctx, InputStream *o, char *buf, size_t bufsiz);
+String* knh_InputStream_readLine(Ctx *ctx, InputStream *o);
+void knh_InputStream_close(Ctx *ctx, InputStream *o);
+int knh_InputStream_isClosed(InputStream *o);
+InputStream *new_InputStream__stdio(Ctx *ctx, FILE *fp);
 /* ../class/konoha/knh_InputStream_api1.c */
 METHOD knh__InputStream_new(Ctx *ctx, knh_sfp_t *sfp);
 void knh_InputStream_setEncoding(Ctx *ctx, InputStream *o, String *enc);
+METHOD knh__InputStream_isClosed(Ctx *ctx, knh_sfp_t *sfp);
 void knh_InputStream__dump(Ctx *ctx, InputStream *b, OutputStream *w, String *m);
 Iterator* knh_InputStream_String__(Ctx *ctx, InputStream *o, Mapper *mpr);
 void knh_InputStream__k(Ctx *ctx, InputStream *o, OutputStream *w, String *m);
@@ -471,20 +474,21 @@ METHOD knh__Int_getSize(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_random(Ctx *ctx, knh_sfp_t *sfp);
 Int* knh_String_Int(Ctx *ctx, String *o, Mapper *mpr);
 String* knh_Int_String(Ctx *ctx, Int *o, Mapper *mpr);
-void knh_Int__s(Ctx *ctx, Int *b, OutputStream *w, String *m);
+void knh_Int__s(Ctx *ctx, Int *o, OutputStream *w, String *m);
 void knh_Int__d(Ctx *ctx, Int *o, OutputStream *w, String *m);
+void knh_Int__u(Ctx *ctx, Int *o, OutputStream *w, String *m);
 void knh_Int__f(Ctx *ctx, Int *o, OutputStream *w, String *m);
-void knh_Int__x(Ctx *ctx, Int *b, OutputStream *w, String *m);
-void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint_t n, int bits);
-void knh_Int__bits(Ctx *ctx, Int *b, OutputStream *w, String *m);
+void knh_Int__x(Ctx *ctx, Int *o, OutputStream *w, String *m);
+void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint64_t n, size_t bits);
+void knh_Int__bits(Ctx *ctx, Int *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_IntUnit.c */
 void knh_IntUnit_struct_init(Ctx *ctx, knh_IntUnit_struct *b, int init, Object *cs);
 void knh_IntUnit_struct_traverse(Ctx *ctx, knh_IntUnit_struct *b, f_traverse gc);
-IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_int_t min, knh_int_t max, knh_int_t defvalue, knh_int_t bf_start, knh_int_t bf_end);
+IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_integer_t min, knh_integer_t max, knh_integer_t defvalue, knh_int_t bf_start, knh_int_t bf_end);
 void knh_IntUnit_initId(Ctx *ctx, IntUnit *b, knh_flag_t flag, knh_class_t cid, String *urn, String *tag);
-void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_int_t min, knh_int_t max);
+void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_integer_t min, knh_integer_t max);
 void knh_IntUnit_init_bfarray(Ctx *ctx, IntUnit *b, knh_int_t bf_start, knh_int_t bf_end);
-void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_int_t v);
+void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_integer_t v);
 /* ../class/konoha/knh_Iterator.c */
 void knh_Iterator_struct_init(Ctx *ctx, knh_Iterator_struct *b, int init, Object *cs);
 void knh_Iterator_struct_copy(Ctx *ctx, knh_Iterator_struct *b, knh_Iterator_struct *b2);
@@ -624,23 +628,24 @@ void knh_Object__empty(Ctx *ctx, Object *b, OutputStream *w, String *m);
 void knh_Object__refc(Ctx *ctx, Object *o, OutputStream *w, String *m);
 void knh_Object__addr(Ctx *ctx, Object *b, OutputStream *w, String *m);
 /* ../class/konoha/knh_OutputStream.c */
-void KNHINIT init_OutputStream(Ctx *ctx);
 void knh_OutputStream_struct_init(Ctx *ctx, knh_OutputStream_struct *b, int init, Object *cs);
 void knh_OutputStream_struct_traverse(Ctx *ctx, knh_OutputStream_struct *b, f_traverse gc);
 Object *knh_OutputStream_open(Ctx *ctx, OutputStream *o, String *urn, String *mode);
 void knh_OutputStream_putc(Ctx *ctx, OutputStream *o, int ch);
 void knh_OutputStream_write(Ctx *ctx, OutputStream *o, knh_bytes_t buf);
 void knh_OutputStream_flush(Ctx *ctx, OutputStream *o);
+void knh_OutputStream_clear(Ctx *ctx, OutputStream *o);
 void knh_OutputStream_close(Ctx *ctx, OutputStream *o);
+int knh_OutputStream_isClosed(OutputStream *o);
 void knh_OutputStream_indent_inc(Ctx *ctx, OutputStream *o);
 void knh_OutputStream_indent_dec(Ctx *ctx, OutputStream *o);
 void knh_OutputStream_write_indent(Ctx *ctx, OutputStream *o);
 void knh_OutputStream_print_(Ctx *ctx, OutputStream *o, knh_bytes_t str, knh_bool_t isnl);
-OutputStream *new_OutputStream__FILE(Ctx *ctx, FILE *fp);
-OutputStream *new_OutputStream__Bytes(Ctx *ctx, Bytes *ba);
+OutputStream *new_OutputStream__stdio(Ctx *ctx, FILE *fp);
 /* ../class/konoha/knh_OutputStream_api1.c */
 METHOD knh__OutputStream_new(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__OutputStream_write(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__OutputStream_isClosed(Ctx *ctx, knh_sfp_t *sfp);
 void knh_OutputStream_setEncoding(Ctx *ctx, OutputStream *o, String *enc);
 METHOD knh__OutputStream_print(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__OutputStream_println(Ctx *ctx, knh_sfp_t *sfp);
@@ -651,6 +656,7 @@ void knh_write__s(Ctx *ctx, OutputStream *w, char *s);
 void knh_write__p(Ctx *ctx, OutputStream *w, void *ptr);
 void knh_write__ifmt(Ctx *ctx, OutputStream *w, char *fmt, knh_int_t n);
 void knh_write__ffmt(Ctx *ctx, OutputStream *w, char *fmt, knh_float_t n);
+void knh_write_integerfmt(Ctx *ctx, OutputStream *w, char *fmt, knh_integer_t n);
 void knh_write__flag(Ctx *ctx, OutputStream *w, knh_flag_t flag);
 void knh_write__type(Ctx *ctx, OutputStream *w, knh_type_t type);
 void knh_write__class(Ctx *ctx, OutputStream *w, knh_class_t cid);
@@ -665,13 +671,17 @@ METHOD knh__Range_new(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Range_new__slice(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Range_new__offset(Ctx *ctx, knh_sfp_t *sfp);
 /* ../class/konoha/knh_Regex.c */
-void KNHINIT init_Regex(Ctx *ctx);
 Regex *new_Regex(Ctx *ctx, String *pattern);
+void knh_Regex_traverse(Ctx *ctx, Regex *o, f_traverse ftr);
+int knh_String_opMatch(Ctx *ctx, String *o, Regex *re);
+METHOD knh__String_opMatch(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Regex_opMatch(Ctx *ctx, knh_sfp_t *sfp);
+Array *knh_Regex_split(Ctx *ctx, Regex *o, String *s);
 void knh_Regex__s(Ctx *ctx, Regex *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_ResultSet.c */
 void knh_ResultSet_struct_init(Ctx *ctx, knh_ResultSet_struct *b, int init, Object *cs);
 void knh_ResultSet_struct_traverse(Ctx *ctx, knh_ResultSet_struct *b, f_traverse ftr);
-ResultSet *knh_ResultSet_next(Ctx *ctx, ResultSet *o);
+knh_boolean_t knh_ResultSet_next(Ctx *ctx, ResultSet *o);
 void knh_ResultSet_initTargetClass(ResultSet *o, knh_class_t tcid);
 knh_index_t knh_ResultSet_index(Ctx *ctx, ResultSet *o, knh_bytes_t name);
 String *knh_ResultSet_getName(Ctx *ctx, ResultSet *o, size_t n);
@@ -711,6 +721,7 @@ knh_bytes_t knh_StringNULL_tobytes(String *o);
 knh_bool_t knh_String_equals(String *o, knh_bytes_t s);
 knh_bool_t knh_String_startsWith(String *b, knh_bytes_t s);
 knh_bool_t knh_String_endsWith(String *b, knh_bytes_t s);
+knh_index_t knh_bytes_indexOf(knh_bytes_t base, knh_bytes_t delim);
 METHOD knh__String_indexOf(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__String_getSize(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp);
@@ -736,6 +747,10 @@ void knh_String__k(Ctx *ctx, String *o, OutputStream *w, String *m);
 knh_bool_t knh_bytes_checkENCODING(knh_bytes_t s);
 size_t knh_bytes_mlen(knh_bytes_t s);
 knh_bytes_t knh_bytes_mofflen(knh_bytes_t m, size_t moff, size_t mlen);
+/* ../class/konoha/knh_StringParser.c */
+Object* new_String_parseOf(Ctx *ctx, String *p);
+knh_type_t	knh_ObjectParser_typing(Ctx *ctx, knh_bytes_t t);
+Object *new_Object_parseOf(Ctx *ctx, String *s);
 /* ../class/konoha/knh_StringUnit.c */
 void knh_StringUnit_struct_init(Ctx *ctx, knh_StringUnit_struct *b, int init, Object *cs);
 void knh_StringUnit_struct_traverse(Ctx *ctx, knh_StringUnit_struct *b, f_traverse gc);
@@ -755,6 +770,7 @@ METHOD knh__System_setOut(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__System_getErr(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__System_setErr(Ctx *ctx, knh_sfp_t *sfp);
 void knh_System__k(Ctx *ctx, System *o, OutputStream *w, String *m);
+void knh_System__dump(Ctx *ctx, System *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Tuple2.c */
 Tuple2 *new_Tuple2(Ctx *ctx, Object *first, Object *second);
 /* ../class/konoha/knh_Tuple2_api1.c */
@@ -764,7 +780,7 @@ Object *knh_Tuple2_get__fast(Tuple2 *b, knh_int_t index);
 void knh_Tuple2__dump(Ctx *ctx, Tuple2 *b, OutputStream *w, String *m);
 /* ../class/konohac/knh_Compiler.c */
 void knh_Compiler_struct_init(Ctx *ctx, knh_Compiler_struct *b, int init, Object *cs);
-void knh_Compiler_struct_traverse(Ctx *ctx, knh_Compiler_struct *b, f_traverse gc);
+void knh_Compiler_struct_traverse(Ctx *ctx, knh_Compiler_struct *b, f_traverse ftr);
 Compiler* knh_Context_getCompiler(Ctx *ctx);
 NameSpace *knh_Context_getNameSpace(Ctx *ctx);
 NameSpace *knh_Context_setNameSpace(Ctx *ctx, String *nsname);
@@ -788,6 +804,8 @@ void knh_KLRCode_struct_traverse(Ctx *ctx, knh_KLRCode_struct *b, f_traverse gc)
 KLRCode* new_KLRCode(Ctx *ctx, knh_fileid_t fileid, knh_bytes_t elf, knh_bytes_t dwarf);
 void knh_Method_setKLRCode(Ctx *ctx, Method *mtd, KLRCode *code);
 knh_bytes_t knh_KLRCode_tobytes(KLRCode *o);
+char *knh_Method_file(Method *mtd);
+int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 /* ../class/konohac/knh_konohac.c */
 Stmt *knh_konohac_parse(Ctx *ctx, InputStream *in);
 void knh_konohac_eval(Ctx *ctx, String *nsname, InputStream *in);
@@ -871,9 +889,9 @@ void knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int
 void knh_StmtCLASS_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtCLASS_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 /* ../class/konohac/knh_StmtDEBUG.c */
-	 void knh_Stmt_toERR(Ctx *ctx, Stmt *stmt, String *msg);
-	 void knh_StmtERR_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
-	 void knh_StmtPRINT_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
+void knh_Stmt_toERR(Ctx *ctx, Stmt *stmt, String *msg);
+void knh_StmtERR_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
+void knh_StmtPRINT_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 void knh_StmtASSERT_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 /* ../class/konohac/knh_StmtDECLLET.c */
 knh_type_t knh_Compiler_typeinfer(Ctx *ctx, Compiler *cpr, knh_type_t type, char *varname);
@@ -889,6 +907,9 @@ void knh_StmtLETMULTI_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, i
 knh_fieldn_t knh_tName_getFieldnOnStack(Ctx *ctx, int level);
 void knh_StmtFOREACH_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtFOREACH_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
+void knh_StmtTRY_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
+void knh_Compiler_cmplsFinally(Ctx *ctx, Compiler *cpr, NameSpace *ns, int level);
+void knh_StmtTRY_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 /* ../class/konohac/knh_StmtEXPR.c */
 void knh_Stmt_setType(Stmt *stmt, knh_type_t type);
 knh_bool_t knh_Term_isTyped(Term *tm);
@@ -908,6 +929,7 @@ void knh_StmtNEW_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_ty
 void knh_StmtMT_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 void knh_StmtMAPCAST_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 /* ../class/konohac/knh_StmtIFLOOP.c */
+int knh_Compiler_llstep(Compiler *cpr);
 knh_short_t knh_Compiler_labelId(Ctx *ctx, Compiler *cpr, knh_bytes_t label);
 void KNH_ASM_LABEL__b(Ctx *ctx, Compiler *cpr, knh_bytes_t t);
 String *knh_Compiler_lstack_label(Ctx *ctx, Compiler *cpr);
@@ -930,8 +952,6 @@ void knh_StmtBREAK_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_
 void knh_StmtGOTO_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 void knh_StmtFOR_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtFOR_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
-void knh_StmtTRY_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
-void knh_StmtTRY_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 void knh_StmtTHROW_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtTHROW_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 /* ../class/konohac/knh_StmtMETA.c */
@@ -1017,6 +1037,21 @@ void knh_tokens_ignore(Ctx *ctx, knh_tokens_t *tc);
 /* ../konoha/deps/cygwin/filesystem__cygwin.c */
 char * knh_format_ospath(char *buf, size_t bufsiz, knh_bytes_t path);
 char * knh_format_homepath(char *buf, size_t bufsiz);
+/* ../konoha/deps/knh_driver_db.c */
+void knh_dbcurfree__NOP(knh_dbcur_t *dbcur);
+void knh_write_USING_SQLITE3(Ctx *ctx, OutputStream *w);
+knh_db_drvapi_t *knh_System_getDefaultDBDriver();
+knh_db_drvapi_t *knh_System_getDBDriver(Ctx *ctx, knh_bytes_t name);
+void KNHINIT init_DB(Ctx *ctx);
+/* ../konoha/deps/knh_driver_io.c */
+knh_iodrv_t *knh_System_getIODriver(Ctx *ctx, knh_bytes_t name);
+knh_iodrv_t knh_System_getDefaultIODriver();
+knh_iodrv_t knh_System_getStdIODriver();
+void KNHINIT init_IO(Ctx *ctx);
+/* ../konoha/deps/knh_driver_regex.c */
+void knh_write_USING_REGEX(Ctx *ctx, OutputStream *w);
+knh_regex_drvapi_t *knh_System_getRegexDriver(Ctx *ctx, knh_bytes_t name);
+void KNHINIT init_Regex(Ctx *ctx);
 /* ../konoha/deps/linux/filesystem__linux.c */
 char * knh_format_ospath(char *buf, size_t bufsiz, knh_bytes_t path);
 char * knh_format_homepath(char *buf, size_t bufsiz);
@@ -1040,14 +1075,6 @@ void *ALT_dlopen(const char* path, int mode);
 void *ALT_dlsym(void* handle, const char* symbol);
 const char *ALT_dlerror();
 int ALT_dlclose(void* handle);
-/* ../konoha/knhapi/konoha_api.c */
-/* ../konoha/knhapi/konoha_libknh.c */
-/* ../konoha/knhapi/konoha_pkgapi.c */
-/* ../konoha/knhapi/konoha_shell.c */
-METHOD knh__Script_eval(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Script_isStatement(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Script_readline(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Script_addHistory(Ctx *ctx, knh_sfp_t *sfp);
 /* ../konoha/konoha.c */
 int main(int argc, char **argv);
 /* ../konoha/runtime/knh_tClass.c */
@@ -1079,7 +1106,7 @@ void knh_tContext_init0(void);
 knh_Context_t *new_Context0(Runtime *runtime, size_t stacksize);
 void knh_Context_traverse(Ctx *ctx, knh_Context_t *o, f_traverse ftr);
 void knh_tContext_traverse(Ctx* ctx, f_traverse f);
-/* ../konoha/runtime/knh_tException.c */
+/* ../konoha/runtime/knh_tExpt.c */
 void knh_tExpt_init0(void);
 void knh_tExpt_traverse(Ctx *ctx, f_traverse ftr);
 knh_class_t knh_tExpt_newId(Ctx *ctx);
@@ -1103,7 +1130,7 @@ Method *knh_tMethod_findMT(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
 /* ../konoha/runtime/knh_tName.c */
 int knh_bytes_isOptionalMT(knh_bytes_t t);
 knh_bytes_t knh_bytes_mtoption(knh_bytes_t t);
-char *knh_format_newFMT(char *buf, size_t bufsiz, knh_bytes_t t, int dot);
+char *knh_format_newFMT(char *buf, size_t bufsiz, knh_bytes_t t, int dot, char *fmt);
 void KNH_TFIELDN__T(Ctx *ctx, knh_fieldn_t fn, char *text);
 String *knh_tfieldn_name(knh_fieldn_t fn);
 knh_fieldn_t knh_tName_get_fnq(Ctx *ctx, knh_bytes_t tname, knh_fieldn_t def);
@@ -1145,23 +1172,33 @@ void knh_tStruct_init0(void);
 void knh_tStruct_traverse(Ctx *ctx, f_traverse f);
 knh_struct_t KNH_TSTRUCT(Ctx *ctx, 		knh_struct_t sid, size_t size, char *name, 		f_tStruct_init f0, f_tStruct_copy f1, /* f_tStruct_compare f2,*/ f_tStruct_traverse f3, 		f_hashCode f4, f_compareTo f5);
 char *knh_tstruct_name(knh_struct_t sid);
+/* ../konoha/runtime/konoha_api.c */
 /* ../konoha/runtime/konoha_call.c */
 void knh_stackf_locals(Ctx *ctx, size_t n);
 knh_vargc_t knh_sfp_argc(Ctx *ctx, knh_sfp_t *varg);
 Array *knh_sfp_toArray(Ctx *ctx, knh_sfp_t *varg);
-void knh_stackf_new(Ctx *ctx, Object **mtdp);
-void knh_sfp_typecheck__DCALL(Ctx *ctx, knh_sfp_t *mbp);
-void knh_sfp_typecheck__MCALL(Ctx *ctx, knh_sfp_t *mbp);
+void knh_dynamiccall(Ctx *ctx, knh_sfp_t *mbp);
 void knh_sfp_dump(Ctx *ctx, knh_sfp_t *sfp);
 /* ../konoha/runtime/konoha_ext.c */
 void knh_srand(knh_uint_t seed);
 knh_uint_t knh_rand();
+/* ../konoha/runtime/konoha_file.c */
+char * knh_format_parentpath(char *buf, size_t bufsiz, knh_bytes_t path, int n);
+char * knh_format_nzpath(char *buf, size_t bufsiz, knh_bytes_t path);
+char * knh_format_catpath(char *buf, size_t bufsiz, knh_bytes_t path, knh_bytes_t file);
+/* ../konoha/runtime/konoha_libknh.c */
 /* ../konoha/runtime/konoha_locale.c */
 char *konoha_encoding();
 char *knh_format_lang(char *buf, size_t bufsiz);
+/* ../konoha/runtime/konoha_pkgapi.c */
 /* ../konoha/runtime/konoha_print.c */
 void knh_sfp_print(Ctx *ctx, knh_sfp_t *sfp, knh_flag_t flag, Object *s, knh_methodn_t mn, Object *o);
 int knh_verbose(void);
+/* ../konoha/runtime/konoha_shell.c */
+METHOD knh__Script_eval(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Script_isStatement(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Script_readline(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Script_addHistory(Ctx *ctx, knh_sfp_t *sfp);
 /* ../konoha/runtime/konoha_sync.c */
 void knh_Object_lock(Ctx *ctx, Object *o);
 void knh_Object_unlock(Ctx *ctx, Object *o);
@@ -1178,10 +1215,6 @@ METHOD knh__Object_opAs(Ctx *ctx, knh_sfp_t *sfp);
 Object* knh_Object_opAs(Ctx *ctx, Object *o, knh_class_t tcid);
 Object *knh_Object_opAs__type(Ctx *ctx, Object *o, knh_type_t reqt, Object *def);
 Exception* new_Exception__type(Ctx *ctx, Object *value, knh_type_t spec_type);
-/* ../konoha/utils/utils_file.c */
-char * knh_format_parentpath(char *buf, size_t bufsiz, knh_bytes_t path, int n);
-char * knh_format_nzpath(char *buf, size_t bufsiz, knh_bytes_t path);
-char * knh_format_catpath(char *buf, size_t bufsiz, knh_bytes_t path, knh_bytes_t file);
 
 #ifdef __cplusplus
 }
