@@ -1,4 +1,4 @@
-﻿/****************************************************************************
+/****************************************************************************
  * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER  
  * 
  * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
@@ -167,6 +167,8 @@ static int knh_message_typedata[] = {
     /* KMSG_EEXTENDS */ 1,
     /* KMSG_EIMPLEMENTS */ 1,
     /* KMSG_DIFFDECL */ 2,
+    /* KMSG_ENESTEDTRY */ 1,
+    /* KMSG_DIFFENAME */ 1,
     /* KMSG_DIFFCLASSN */ 2,
     /* KMSG_DIFFNEWTYPE */ 1,
     /* KMSG_DIFFRTYPE */ 1,
@@ -989,6 +991,22 @@ static char* knh_message_data[] = {
 #endif
         "DIFFDECL",
     
+    /* KMSG_ENESTEDTRY */ 
+        /* en */ "Don't use nested try clause",
+#ifdef KNH_USING_I18N
+        /* ja */ "try 節はネストして使うことはできません" ,
+
+#endif
+        "ENESTEDTRY",
+    
+    /* KMSG_DIFFENAME */ 
+        /* en */ "Don't use different Exception name in the catch clause",
+#ifdef KNH_USING_I18N
+        /* ja */ "同じ変数名で例外をcatch してくださいネ" ,
+
+#endif
+        "DIFFENAME",
+    
     /* KMSG_DIFFCLASSN */ 
         /* en */ "The Class names are not identical",
 #ifdef KNH_USING_I18N
