@@ -170,6 +170,7 @@ void knh_tObject_free(knh_Object_t *t)
 	int i;
 	for(i = 0; i < KNH_TOBJECT_SIZE; i++) {
 		if(t[i].h.magic == 0) continue;
+#ifdef KNH_HOBJECT_REFC
 		DBG_(
 		fprintf(stderr, "Memory Leak cid = %d,%s, refc=%d\n", (int)t[i].h.cid, STRUCTN(t[i].h.bcid), (int)t[i].h.refc);
 		{
@@ -183,6 +184,7 @@ void knh_tObject_free(knh_Object_t *t)
 			break;
 			}
 		} )
+#endif
 	}
 	KNH_FREE(t, SIZEOF_TOBJECT);
 	t = NULL;
@@ -221,7 +223,9 @@ knh_Object_t *new_PObject__NNctx(Ctx *ctx, knh_flag_t flag, knh_class_t bcid, kn
 		knh_statUsedObjectSize++;
 #endif
 		o->h.magic = KNH_OBJECT_MAGIC;
-		o->h.refc = 0;
+#ifdef KNH_HOBJECT_REFC
+		o->h.refc = KNH_HOBJECT_REFC_INIT;
+#endif
 		o->h.flag = flag;
 		o->h.bcid = bcid;
 		o->h.cid  = cid;
@@ -254,7 +258,9 @@ knh_Object_t *new_PObject0(Ctx *ctx, knh_flag_t flag, knh_class_t bcid, knh_clas
 			knh_statUsedObjectSize++;
 	#endif
 			o->h.magic = KNH_OBJECT_MAGIC;
-			o->h.refc = 0;
+#ifdef KNH_HOBJECT_REFC
+			o->h.refc = KNH_HOBJECT_REFC_INIT;
+#endif
 			o->h.flag = flag;
 			o->h.bcid = bcid;
 			o->h.cid  = cid;
@@ -321,7 +327,9 @@ knh_Object_t *new_ObjectX_malloc(Ctx *ctx, knh_flag_t flag, knh_class_t bcid, kn
 		knh_statUsedObjectSize++;
 #endif
 	o->h.magic = KNH_OBJECT_MAGIC;
-	o->h.refc = 0;
+#ifdef KNH_HOBJECT_REFC
+	o->h.refc = KNH_HOBJECT_REFC_INIT;
+#endif
 	o->h.flag = flag;
 	o->h.cid  = cid;
 	if(size > 0) {
@@ -362,7 +370,9 @@ Object *new_Object(Ctx *ctx, knh_flag_t flag, knh_class_t cid)
 #endif
 
 		o->h.magic = KNH_OBJECT_MAGIC;
-		o->h.refc = 0;
+#ifdef KNH_HOBJECT_REFC
+		o->h.refc = KNH_HOBJECT_REFC_INIT;
+#endif
 		o->h.flag = (knh_tClass[cid].oflag | flag);
 		o->h.cid  = cid;
 
@@ -481,7 +491,7 @@ void knh_Object_free(Ctx *ctx, knh_Object_t *o)
 			if(knh_Nue_isGCHook(v)) {
 				o->h.magic = KNH_OBJECT_MAGIC;
 				knh_Object_RCinc(o);
-				knh_throwException(ctx, new_Exception__Nue(ctx, v));
+				knh_throwException(ctx, new_Exception__Nue(ctx, v), NULL, 0);
 			}
 			if(v->orign != NULL) {
 				KNH_ASSERT(IS_bString(v->orign));
@@ -540,11 +550,17 @@ void knh_Object_free(Ctx *ctx, knh_Object_t *o)
 		}
 		break;
 
+	case CLASS_Regex :
+		{
+			knh_Regex_traverse(ctx, (knh_Regex_t*)o, knh_Object_RCsweep);
+			break;
+		}
+
 	case CLASS_Context:
 		{
 			knh_Context_traverse(ctx, (Context*)o, knh_Object_RCsweep);
-			return ;
 		}
+		return ;
 
 	default :
 		{
@@ -586,6 +602,9 @@ void knh_Object_free(Ctx *ctx, knh_Object_t *o)
 //				DBG2_P("sid=%d,%s size=%d,%d", o->h.bcid, STRUCTN(o->h.bcid), size, knh_tClass[o->h.cid].size);
 //			}
 			DBG_(KNH_ASSERT(size == knh_tClass[o->h.cid].size);)
+			if(knh_tClass[o->h.cid].size == 0) {
+				DBG2_P("sid=%d,%s size=%d,%d", o->h.bcid, STRUCTN(o->h.bcid), size, knh_tClass[o->h.cid].size);
+			}
 			KNH_FREE(o->ref, knh_tClass[o->h.cid].size);
 			o->ref = NULL;
 		}
@@ -680,6 +699,12 @@ void knh_Object_traverse(Ctx *ctx, knh_Object_t *o, f_traverse ftr)
 		}
 		break;
 
+	case CLASS_Regex :
+		{
+			knh_Regex_traverse(ctx, (knh_Regex_t*)o, ftr);
+			break;
+		}
+
 	case CLASS_Context:
 		{
 			knh_Context_traverse(ctx, (Context*)o, ftr);
@@ -746,13 +771,6 @@ void knh_tString_init0(void);
 #define _knh_tMethodField(n)                 (MethodField*)knh_Array_n(DP(knh_rootSystem)->tMethodFields, n)
 #define _knh_tMethodField_size               knh_Array_size(DP(knh_rootSystem)->tMethodFields)
 
-///* ------------------------------------------------------------------------ */
-//
-//Any* ALT_NULL(void)
-//{
-//	return knh_constNull;
-//}
-
 /* ------------------------------------------------------------------------ */
 
 Object *new_Nue__T(Ctx *ctx, char *text)
@@ -816,7 +834,9 @@ KNHAPI(Int*) new_Int__fast(Ctx *ctx, knh_class_t cid, knh_integer_t value)
 		knh_statUsedObjectSize++;
 #endif
 		o->h.magic = KNH_OBJECT_MAGIC;
-		o->h.refc = 0;
+#ifdef KNH_HOBJECT_REFC
+		o->h.refc = KNH_HOBJECT_REFC_INIT;
+#endif
 		o->h.flag = FLAG_Int;
 		o->h.bcid = CLASS_Int;
 		o->h.cid  = cid;
@@ -854,7 +874,9 @@ KNHAPI(Float*) new_Float__fast(Ctx *ctx, knh_class_t cid, knh_float_t value)
 		knh_statUsedObjectSize++;
 #endif
 		o->h.magic = KNH_OBJECT_MAGIC;
-		o->h.refc = 0;
+#ifdef KNH_HOBJECT_REFC
+		o->h.refc = KNH_HOBJECT_REFC_INIT;
+#endif
 		o->h.flag = FLAG_Float;
 		o->h.bcid = CLASS_Float;
 		o->h.cid  = cid;
@@ -889,9 +911,9 @@ knh_System_t *new_System0(void)
 	knh_System_t *o = (knh_System_t*)new_ObjectX_malloc(NULL, FLAG_System, CLASS_Object, CLASS_System, sizeof(knh_System_struct));
 	KNH_INITv(DP(o)->ns,    new_NameSpace(NULL, (NameSpace*)KNH_NULL, TS_EMPTY));
 	KNH_INITv(DP(o)->enc,   new_String__T(NULL, konoha_encoding()));
-	KNH_INITv(DP(o)->in,    new_InputStream__FILE(NULL, stdin));
-	KNH_INITv(DP(o)->out,   new_OutputStream__FILE(NULL, stdout));
-	KNH_INITv(DP(o)->err,   new_OutputStream__FILE(NULL, stderr));
+	KNH_INITv(DP(o)->in,    new_InputStream__stdio(NULL, stdin));
+	KNH_INITv(DP(o)->out,   new_OutputStream__stdio(NULL, stdout));
+	KNH_INITv(DP(o)->err,   new_OutputStream__stdio(NULL, stderr));
 	knh_InputStream_setEncoding(NULL, DP(o)->in,   DP(o)->enc);
 	knh_OutputStream_setEncoding(NULL, DP(o)->out, DP(o)->enc);
 	knh_OutputStream_setEncoding(NULL, DP(o)->err, DP(o)->enc);
@@ -1040,6 +1062,7 @@ void knh_tObject_traverse(Ctx *ctx, f_traverse ftr)
 	ftr(ctx, (Object*)knh_constVoid);
 	ftr(ctx, (Object*)knh_constNull);
 
+	knh_tExpt_traverse(ctx, ftr);
 	knh_tClass_traverse(ctx, ftr);
 
 	if(IS_SWEEP(ftr)) {
